package com.ruoyi.brewery.mapper;

import java.util.List;
import com.ruoyi.brewery.domain.WyBreweryAuth;

/**
 * 主体认证信息Mapper接口
 * 
 * @author ruoyi
 * @date 2024-12-21
 */
public interface WyBreweryAuthMapper 
{
    /**
     * 查询主体认证信息
     * 
     * @param id 主体认证信息主键
     * @return 主体认证信息
     */
    public WyBreweryAuth selectWyBreweryAuthById(Long id);

    public WyBreweryAuth selectWyBreweryAuthByBreweryId(Long breweryId);
    /**
     * 查询主体认证信息列表
     * 
     * @param wyBreweryAuth 主体认证信息
     * @return 主体认证信息集合
     */
    public List<WyBreweryAuth> selectWyBreweryAuthList(WyBreweryAuth wyBreweryAuth);

    /**
     * 新增主体认证信息
     * 
     * @param wyBreweryAuth 主体认证信息
     * @return 结果
     */
    public int insertWyBreweryAuth(WyBreweryAuth wyBreweryAuth);

    /**
     * 修改主体认证信息
     * 
     * @param wyBreweryAuth 主体认证信息
     * @return 结果
     */
    public int updateWyBreweryAuth(WyBreweryAuth wyBreweryAuth);

    /**
     * 删除主体认证信息
     * 
     * @param id 主体认证信息主键
     * @return 结果
     */
    public int deleteWyBreweryAuthById(Long id);

    public int deleteWyBreweryAuthByBreweryId(Long breweryId);
    /**
     * 批量删除主体认证信息
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteWyBreweryAuthByIds(Long[] ids);
}
